@@ -7,8 +7,9 @@ mod r#impl;
 mod kind;
 mod target;
 
+#[cfg(feature = "metadata")]
+use std::any::type_name;
 use std::{
-	any::type_name,
 	fmt::{Debug, Formatter, Result as FmtResult},
 	future::Future,
 	iter::FromIterator,
@@ -30,7 +31,7 @@ pub use self::{
 	},
 	target::OperationTarget,
 };
-use crate::{backend::Backend, util::InnerUnwrap, Entry, Gateway, IndexEntry, Key};
+use crate::{backend::Backend, util::InnerUnwrap, Entry, IndexEntry, Key, Starchart};
 
 #[cfg(all(feature = "metadata", not(tarpaulin_include)))]
 const METADATA_KEY: &str = "__metadata__";
@@ -64,10 +65,10 @@ pub type UpdateTableAction<S> = Action<S, UpdateOperation, TableTarget>;
 /// A type alias for an [`Action`] with [`DeleteOperation`] and [`TableTarget`] as the parameters.
 pub type DeleteTableAction<S> = Action<S, DeleteOperation, TableTarget>;
 
-/// An [`Action`] for easy [`CRUD`] operations within a [`Gateway`].
+/// An [`Action`] for easy [`CRUD`] operations within a [`Starchart`].
 ///
 /// [`CRUD`]: https://en.wikipedia.org/wiki/Create,_read,_update_and_delete
-/// [`Gateway`]: crate::Gateway
+/// [`Starchart`]: crate::Starchart
 #[derive(Serialize, Deserialize)]
 #[must_use = "an action alone has no side effects"]
 pub struct Action<S, C: CrudOperation, T: OpTarget> {
@@ -405,7 +406,7 @@ unsafe impl<S: Entry + Sync, C: CrudOperation, T: OpTarget> Sync for Action<S, C
 impl<B: Backend, S: Entry + 'static> ActionRunner<B, (), ActionRunError<B::Error>>
 	for Action<S, CreateOperation, EntryTarget>
 {
-	unsafe fn run(self, gateway: &Gateway<B>) -> ActionRunFuture<'_, (), B> {
+	unsafe fn run(self, gateway: &Starchart<B>) -> ActionRunFuture<'_, (), B> {
 		// Create the lock outside of the async block, as the guard is invalid if created in async context.
 		let lock = gateway.guard.write();
 		let res = Box::pin(async move {
@@ -443,7 +444,7 @@ impl<B: Backend, S: Entry + 'static> ActionRunner<B, (), ActionRunError<B::Error
 impl<B: Backend, S: Entry + 'static> ActionRunner<B, Option<S>, ActionRunError<B::Error>>
 	for Action<S, ReadOperation, EntryTarget>
 {
-	unsafe fn run(self, gateway: &Gateway<B>) -> ActionRunFuture<'_, Option<S>, B> {
+	unsafe fn run(self, gateway: &Starchart<B>) -> ActionRunFuture<'_, Option<S>, B> {
 		let lock = gateway.guard.read();
 		let res = Box::pin(async move {
 			let table_name = self.table.clone().inner_unwrap();
@@ -471,7 +472,7 @@ impl<B: Backend, S: Entry + 'static> ActionRunner<B, Option<S>, ActionRunError<B
 impl<B: Backend, S: Entry + 'static> ActionRunner<B, (), ActionRunError<B::Error>>
 	for Action<S, UpdateOperation, EntryTarget>
 {
-	unsafe fn run(self, gateway: &Gateway<B>) -> ActionRunFuture<'_, (), B> {
+	unsafe fn run(self, gateway: &Starchart<B>) -> ActionRunFuture<'_, (), B> {
 		let lock = gateway.guard.write();
 		let res = Box::pin(async move {
 			let table = self.table.clone().inner_unwrap();
@@ -503,7 +504,7 @@ impl<B: Backend, S: Entry + 'static> ActionRunner<B, (), ActionRunError<B::Error
 impl<B: Backend, S: Entry + 'static> ActionRunner<B, bool, ActionRunError<B::Error>>
 	for Action<S, DeleteOperation, EntryTarget>
 {
-	unsafe fn run(self, gateway: &Gateway<B>) -> ActionRunFuture<'_, bool, B> {
+	unsafe fn run(self, gateway: &Starchart<B>) -> ActionRunFuture<'_, bool, B> {
 		let lock = gateway.guard.write();
 		let res = Box::pin(async move {
 			let table = self.table.inner_unwrap();
@@ -537,7 +538,7 @@ where
 	I: FromIterator<S>,
 {
 	#[cfg(not(tarpaulin_include))]
-	unsafe fn run(self, gateway: &Gateway<B>) -> ActionRunFuture<'_, I, B> {
+	unsafe fn run(self, gateway: &Starchart<B>) -> ActionRunFuture<'_, I, B> {
 		let lock = gateway.guard.read();
 		let res = Box::pin(async move {
 			let table = self.table.clone().inner_unwrap();
@@ -547,9 +548,10 @@ where
 			#[cfg(all(feature = "metadata", not(tarpaulin_include)))] // coverage:ignore-line
 			self.check_metadata(backend, &table).await?;
 
-			let keys = backend
-				.get_keys::<Vec<_>>(&table)
-				.await?
+			let keys = backend.get_keys::<Vec<_>>(&table).await?;
+
+			#[cfg(feature = "metadata")]
+			let keys = keys
 				.into_iter()
 				.filter(|value| value != METADATA_KEY)
 				.collect::<Vec<_>>();
@@ -573,7 +575,7 @@ where
 impl<B: Backend, S: Entry + 'static> ActionRunner<B, (), ActionRunError<B::Error>>
 	for Action<S, CreateOperation, TableTarget>
 {
-	unsafe fn run(self, gateway: &Gateway<B>) -> ActionRunFuture<'_, (), B> {
+	unsafe fn run(self, gateway: &Starchart<B>) -> ActionRunFuture<'_, (), B> {
 		let lock = gateway.guard.write();
 		let res = Box::pin(async move {
 			let table = self.table.inner_unwrap();
@@ -603,7 +605,7 @@ impl<B: Backend, S: Entry + 'static> ActionRunner<B, (), ActionRunError<B::Error
 impl<B: Backend, S: Entry + 'static> ActionRunner<B, bool, ActionRunError<B::Error>>
 	for Action<S, DeleteOperation, TableTarget>
 {
-	unsafe fn run(self, gateway: &Gateway<B>) -> ActionRunFuture<'_, bool, B> {
+	unsafe fn run(self, gateway: &Starchart<B>) -> ActionRunFuture<'_, bool, B> {
 		let lock = gateway.guard.write();
 		let res = Box::pin(async move {
 			let table = self.table.inner_unwrap();
@@ -628,7 +630,7 @@ impl<B: Backend, S: Entry + 'static> ActionRunner<B, bool, ActionRunError<B::Err
 	}
 }
 
-#[cfg(all(test, feature = "cache", feature = "metadata"))]
+#[cfg(all(test, feature = "memory", feature = "metadata"))]
 mod tests {
 	use serde::{Deserialize, Serialize};
 
@@ -639,7 +641,7 @@ mod tests {
 		UpdateEntryAction, UpdateOperation,
 	};
 	use crate::{
-		action::ActionRunError, backend::CacheBackend, error::CacheError, Gateway, IndexEntry,
+		action::ActionRunError, backend::MemoryBackend, error::MemoryError, IndexEntry, Starchart,
 	};
 
 	#[derive(
@@ -659,15 +661,15 @@ mod tests {
 		}
 	}
 
-	async fn setup_gateway() -> Gateway<CacheBackend> {
-		let backend = CacheBackend::new();
-		Gateway::new(backend).await.unwrap()
+	async fn setup_gateway() -> Starchart<MemoryBackend> {
+		let backend = MemoryBackend::new();
+		Starchart::new(backend).await.unwrap()
 	}
 
-	async fn setup_table(gateway: &Gateway<CacheBackend>) {
+	async fn setup_table(gateway: &Starchart<MemoryBackend>) {
 		let action: CreateTableAction<Settings> = Action::new().set_table("table").clone();
 
-		gateway.run(action).await.unwrap().unwrap()
+		gateway.run(action).await.unwrap().unwrap();
 	}
 
 	#[test]
@@ -693,6 +695,9 @@ mod tests {
 
 	#[test]
 	fn conversion_methods() {
+		#[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, Serialize, Deserialize)]
+		struct NewSettings;
+
 		let action: Action<Settings, ReadOperation, EntryTarget> = Action::new();
 
 		let create = action.into_create();
@@ -713,9 +718,6 @@ mod tests {
 		let entry = table.into_entry();
 		assert_eq!(entry.target(), OperationTarget::Entry);
 
-		#[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, Serialize, Deserialize)]
-		struct NewSettings;
-
 		let new_entry = entry.with_entry::<NewSettings>();
 		assert!(new_entry.data.is_none());
 	}
@@ -850,7 +852,7 @@ mod tests {
 
 	#[tokio::test]
 	#[cfg_attr(miri, ignore)]
-	async fn basic_run() -> Result<(), ActionError<CacheError>> {
+	async fn basic_run() -> Result<(), ActionError<MemoryError>> {
 		let gateway = setup_gateway().await;
 		let mut action: Action<Settings, CreateOperation, TableTarget> = Action::new();
 
@@ -904,7 +906,7 @@ mod tests {
 
 	#[tokio::test]
 	#[cfg_attr(miri, ignore)]
-	async fn duplicate_creates() -> Result<(), ActionError<CacheError>> {
+	async fn duplicate_creates() -> Result<(), ActionError<MemoryError>> {
 		let gateway = setup_gateway().await;
 		setup_table(&gateway).await;
 
@@ -925,7 +927,7 @@ mod tests {
 
 	#[tokio::test]
 	#[cfg_attr(miri, ignore)]
-	async fn read_and_update() -> Result<(), ActionError<CacheError>> {
+	async fn read_and_update() -> Result<(), ActionError<MemoryError>> {
 		let gateway = setup_gateway().await;
 		setup_table(&gateway).await;
 		{
@@ -967,7 +969,7 @@ mod tests {
 
 	#[tokio::test]
 	#[cfg_attr(miri, ignore)]
-	async fn deletes() -> Result<(), ActionError<CacheError>> {
+	async fn deletes() -> Result<(), ActionError<MemoryError>> {
 		let gateway = setup_gateway().await;
 		setup_table(&gateway).await;
 
@@ -994,7 +996,7 @@ mod tests {
 		let mut read_table: ReadTableAction<Settings> = Action::new();
 		read_table.set_table("table");
 
-		let res: Result<Vec<_>, ActionRunError<CacheError>> = gateway.run(read_table).await?;
+		let res: Result<Vec<_>, ActionRunError<MemoryError>> = gateway.run(read_table).await?;
 
 		assert!(res.is_err());
 
