@@ -14,8 +14,8 @@ use tokio_stream::{wrappers::ReadDirStream, StreamExt};
 
 use super::{
 	future::{
-		CreateFuture, CreateTableFuture, DeleteFuture, GetFuture, GetKeysFuture, HasFuture,
-		HasTableFuture, InitFuture, ReplaceFuture, UpdateFuture,
+		CreateFuture, CreateTableFuture, DeleteFuture, DeleteTableFuture, GetFuture, GetKeysFuture,
+		HasFuture, HasTableFuture, InitFuture, ReplaceFuture, UpdateFuture,
 	},
 	Backend,
 };
@@ -23,6 +23,7 @@ use crate::{util::InnerUnwrap, Entry};
 
 /// An error occurred from an [`FsBackend`].
 #[derive(Debug, Error)]
+#[cfg(feature = "fs")]
 pub enum FsError {
 	/// An IO error occurred.
 	#[error(transparent)]
@@ -57,6 +58,7 @@ macro_rules! handle_io_result {
 /// The trait for all File System based backends to implement
 ///
 /// This makes it easier to implement different file-system based databases.
+#[cfg(feature = "fs")]
 pub trait FsBackend: Send + Sync {
 	/// The base extension of the files.
 	const EXTENSION: &'static str;
@@ -124,7 +126,7 @@ pub trait FsBackend: Send + Sync {
 	fn base_directory(&self) -> PathBuf;
 }
 
-#[cfg_attr(docsrs, doc(cfg(feature = "fs")))]
+#[cfg(feature = "fs")]
 impl<RW: FsBackend> Backend for RW {
 	type Error = FsError;
 
@@ -153,10 +155,7 @@ impl<RW: FsBackend> Backend for RW {
 		})
 	}
 
-	fn delete_table<'a>(
-		&'a self,
-		table: &'a str,
-	) -> super::future::DeleteTableFuture<'a, Self::Error> {
+	fn delete_table<'a>(&'a self, table: &'a str) -> DeleteTableFuture<'a, Self::Error> {
 		Box::pin(async move {
 			if self.has_table(table).await? {
 				fs::remove_dir(self.resolve_path(&[table])).await?;
